@@ -98,14 +98,14 @@ def linear_to_mel(spec, n_fft, num_mels, sr, fmin=0, fmax=None):
     spec = spectral_normalize_torch(spec)
     return spec
 
-def get_feature(audio, sr=22050, n_fft=1024, hop_size=256, win_size=1024, n_mel=80):
+def get_feature(audio, sr=22050, n_fft=1024, hop_size=256, win_size=1024, n_mel=80, need_f0=True, need_energy=True, need_mel=True):
 
     if audio.max() > 1:
         audio = torch.FloatTensor(audio.astype(np.float32))
         audio_norm = audio / 2 ** 15
         audio_norm = audio_norm.unsqueeze(0)
     else:
-        audio = torch.FloatTensor(audio.astype(np.float32))
+        audio_norm = torch.FloatTensor(audio.astype(np.float32))
         audio_norm = audio_norm.unsqueeze(0)
 
     spec = audio_to_linear(audio_norm,
@@ -114,28 +114,33 @@ def get_feature(audio, sr=22050, n_fft=1024, hop_size=256, win_size=1024, n_mel=
                              hop_size=hop_size,
                              win_size=win_size)
 
-
-    mel = linear_to_mel(spec,
-                            n_fft=n_fft,
-                            num_mels=n_mel,
-                            sr=sr
-                            )
+    if need_mel:
+        mel = linear_to_mel(spec,
+                                n_fft=n_fft,
+                                num_mels=n_mel,
+                                sr=sr
+                                )
+    else:
+        mel=spec
     
-    audio_norm = torch.nn.functional.pad(audio_norm, (int((n_fft-hop_size)/2), int((n_fft-hop_size)/2)), mode='reflect')
+    # audio_norm = torch.nn.functional.pad(audio_norm, (int((n_fft-hop_size)/2), int((n_fft-hop_size)/2)), mode='reflect')
     
-
-    F0 = librosa.pyin(y=audio_norm.numpy(),
-                      fmin=librosa.note_to_hz('C2'),
-                      fmax=librosa.note_to_hz('C7'),
-                      sr=sr,
-                      frame_length=n_fft,
-                      hop_length=hop_size,
-                      center=False)[0].squeeze(0)
+    if need_f0:
+        F0 = librosa.pyin(y=audio_norm.numpy(),
+                        fmin=librosa.note_to_hz('C2'),
+                        fmax=librosa.note_to_hz('C7'),
+                        sr=sr,
+                        frame_length=n_fft,
+                        hop_length=hop_size,
+                        center=False)[0].squeeze(0)
+    else:
+        F0 = np.zeros(spec.size(1))
 
 
-
-    eng = librosa.feature.rms(y=audio_norm.numpy(), frame_length=n_fft, hop_length=hop_size, center=False)[0]
-    
+    if need_energy:
+        eng = librosa.feature.rms(y=audio_norm.numpy(), frame_length=n_fft, hop_length=hop_size, center=False)[0]
+    else:
+        eng = np.zeros(spec.size(1))
     
     
     audio_norm = audio_norm.squeeze(0)
