@@ -3,7 +3,7 @@ import torch
 import os
 import logging
 import pickle
-
+import random
 
 def disable_logger(logger_name: List):
     for n in logger_name:
@@ -24,4 +24,8 @@ def load_text(filename):
 
 def dump_pickle(data, filename):
     with open(filename, "wb") as f:
-        pickle.dump(data, f)
\ No newline at end of file
+        pickle.dump(data, f)
+        
+
+def random_str(length):
+    return os.urandom(length).hex()
\ No newline at end of file
